@@ -4,7 +4,8 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.0995';
+
+$VERSION = '0.0996';
 
 use Carp;
 use File::Path;
@@ -138,6 +139,7 @@ mongo db is the fastest, but sqlite will always work.',
 
     $newconfig{ port } = _ask( "Port to run yote server on?", undef, 80 );
     $newconfig{ threads } = _ask( "Number of threads to start the serve with?", undef, 10 );
+    $newconfig{ threads } = _ask( "How many threads should be run?", undef, 10 );
 
     # this is as secure as the file permissions of the config file, and as secure as the data store is itself.
     $newconfig{ root_account  } = _ask( "Root Account name", undef, 'root' );
@@ -247,7 +249,8 @@ sub run {
 
     my $s = Yote::WebAppServer->new;
 
-    _log "Starting Server";
+    my $start_time = localtime();
+    _log "Starting Server at $start_time";
     my $args = Data::Dumper->Dump([\%config]);
     _log $args;
 
